@@ -66,6 +66,69 @@ dd_KI_lamuN = function(ddmodel,pars,N)
     return(c(laMN,muMN,laSN,muSN))
 }
 
+
+
+#' Function to simulate a key innovation in macro-evolution with the innovative
+#' clade decoupling from the diversity-dependent diversification dynamics of
+#' the main clade
+#' 
+#' Simulating a diversity-dependent diversification process where at a given
+#' time a new clade emerges with different inherent speciation rate and
+#' extinction rate and clade-level carrying capacity and with decoupled
+#' dynamics
+#' 
+#' 
+#' @param pars Vector of parameters: \cr \cr \code{pars[1]} corresponds to
+#' lambda_M (speciation rate of the main clade) \cr \code{pars[2]} corresponds
+#' to mu_M (extinction rate of the main clade) \cr \code{pars[3]} corresponds
+#' to K_M (clade-level carrying capacity of the main clade) \code{pars[4]}
+#' corresponds to lambda_S (speciation rate of the subclade) \cr \code{pars[5]}
+#' corresponds to mu_S (extinction rate of the subclade) \cr \code{pars[5]}
+#' corresponds to K_S (clade-level carrying capacity of the subclade) \cr
+#' \code{pars[7]} tinn, the time the shift in rates occurs in the lineage
+#' leading to the subclade
+#' @param age Sets the crown age for the simulation
+#' @param ddmodel Sets the model of diversity-dependence: \cr \code{ddmodel ==
+#' 1} : linear dependence in speciation rate with parameter K (= diversity
+#' where speciation = extinction)\cr \code{ddmodel == 1.3} : linear dependence
+#' in speciation rate with parameter K' (= diversity where speciation = 0)\cr
+#' \code{ddmodel == 2} : exponential dependence in speciation rate with
+#' parameter K (= diversity where speciation = extinction)\cr \code{ddmodel ==
+#' 2.1} : variant of exponential dependence in speciation rate with offset at
+#' infinity\cr \code{ddmodel == 2.2} : 1/n dependence in speciation rate\cr
+#' \code{ddmodel == 2.3} : exponential dependence in speciation rate with
+#' parameter x (= exponent)\cr \code{ddmodel == 3} : linear dependence in
+#' extinction rate \cr \code{ddmodel == 4} : exponential dependence in
+#' extinction rate \cr \code{ddmodel == 4.1} : variant of exponential
+#' dependence in extinction rate with offset at infinity \cr \code{ddmodel ==
+#' 4.2} : 1/n dependence in extinction rate with offset at infinity
+#' @return \item{ out }{ A list with the following elements: The first element
+#' is the tree of extant species in phylo format \cr The second element is the
+#' tree of all species, including extinct species, in phylo format \cr The
+#' third element is a matrix of all species where \cr - the first column is the
+#' time at which a species is born \cr - the second column is the label of the
+#' parent of the species; positive and negative values only indicate whether
+#' the species belongs to the left or right crown lineage \cr - the third
+#' column is the label of the daughter species itself; positive and negative
+#' values only indicate whether the species belongs to the left or right crown
+#' lineage \cr - the fourth column is the time of extinction of the species \cr
+#' If the fourth element equals -1, then the species is still extant.\cr - the
+#' fifth column indicates whether the species belong to the main clade (0) or
+#' the subclade (1)\cr The fourth element is the subclade tree of extant
+#' species (without stem) \cr The fifth element is the subclade tree of all
+#' species (without stem) \cr The sixth element is the same as the first,
+#' except that it has attributed 0 for the main clade and 1 for the subclade\cr
+#' The seventh element is the same as the Second, except that it has attributed
+#' 0 for the main clade and 1 for the subclade\cr The sixth and seventh element
+#' will be NULL if the subclade does not exist (because it went extinct).  }
+#' @author Rampal S. Etienne
+#' @references - Etienne, R.S. et al. 2012, Proc. Roy. Soc. B 279: 1300-1309,
+#' doi: 10.1098/rspb.2011.1439 \cr - Etienne, R.S. & B. Haegeman 2012. Am. Nat.
+#' 180: E75-E89, doi: 10.1086/667574
+#' @keywords models
+#' @examples
+#'  dd_KI_sim(c(0.2,0.1,20,0.1,0.05,30,4),10) 
+#' @export dd_KI_sim
 dd_KI_sim = function(pars,age,ddmodel = 1)
 {
 # Simulation of diversity-dependent process
@@ -138,7 +201,7 @@ while(done == 0)
     laSN = ff[3]
     muSN = ff[4]
     denom = (laMN + muMN) * NM[i] + (laSN + muSN) * NS[i]
-    t[i + 1] = t[i] - log(runif(1)) / denom
+    t[i + 1] = t[i] + stats::rexp(1,denom)
     if(t[i + 1] > tinn & t[i] < tinn)
     {
          NM[i] = NM[i] - 1
@@ -152,7 +215,7 @@ while(done == 0)
          laSN = ff[3]
          muSN = ff[4]
          denom = (laMN + muMN) * NM[i] + (laSN + muSN) * NS[i]
-         t[i + 1] = tinn - log(runif(1)) / denom
+         t[i + 1] = tinn + stats::rexp(1,denom)
     }
     while(t[i + 1] <= age)
     {
@@ -207,7 +270,7 @@ while(done == 0)
             laSN = ff[3]
             muSN = ff[4]
             denom = (laMN + muMN) * NM[i] + (laSN + muSN) * NS[i]
-            t[i + 1] = t[i] - log(runif(1)) / denom
+            t[i + 1] = t[i] + stats::rexp(1,denom)
             if(t[i + 1] > tinn & t[i] < tinn)
             {
                NM[i] = NM[i] - 1
@@ -221,7 +284,7 @@ while(done == 0)
                L[abs(linlistS),5] = 1
                linlistM = linlistM[-which(linlistM == linlistS)]
                denom = (laMN + muMN) * NM[i] + (laSN + muSN) * NS[i]
-               t[i + 1] = tinn - log(runif(1)) / denom
+               t[i + 1] = tinn + stats::rexp(1,denom)
             }
         }
     }
@@ -241,9 +304,9 @@ tes = L2phylo(L[,1:4],dropextinct = T)
 tas = L2phylo(L[,1:4],dropextinct = F)
 tesS = NULL
 tes2 = NULL
-par(mfrow = c(2,1))
-plot(tes)
-plot(tas)
+graphics::par(mfrow = c(2,1))
+graphics::plot(tes)
+graphics::plot(tas)
 cols = c("blue","red")
 names(cols) = c(0,1)
 if(length(linlistS) > 0)
@@ -256,14 +319,14 @@ if(length(linlistS) > 0)
    }
    else if(length(linlistS) > 1)
    {
-      m = getMRCA(phy = tes,tip = namesS)
-      tesS = extract.clade(phy = tes,node = m)
-      b2 = age - node.depth.edgelength(tes)[m]
+      m = ape::getMRCA(phy = tes,tip = namesS)
+      tesS = ape::extract.clade(phy = tes,node = m)
+      b2 = age - ape::node.depth.edgelength(tes)[m]
    }  
    m0 = tes$edge[which(tes$edge[,2] == m),1]
-   b1 = age - node.depth.edgelength(tes)[m0]
-   tes2 = paintSubTree(tes,node = m,state = "1",anc.state = "0",stem = (pars[7] - b2)/(b1 - b2))
-   plotSimmap(tes2,cols,lwd = 3,pts = F)
+   b1 = age - ape::node.depth.edgelength(tes)[m0]
+   tes2 = phytools::paintSubTree(tes,node = m,state = "1",anc.state = "0",stem = (pars[7] - b2)/(b1 - b2))
+   phytools::plotSimmap(tes2,cols,lwd = 3,pts = F)
 }
 tasS = NULL
 tas2 = NULL
@@ -278,16 +341,16 @@ if(length(allS) > 0)
    }
    else if(length(allS) > 1)
    {
-      m = getMRCA(phy = tas,tip = namesS)
-      tasS = extract.clade(phy = tas,node = m)
-      b2 = age - node.depth.edgelength(tas)[m]
+      m = ape::getMRCA(phy = tas,tip = namesS)
+      tasS = ape::extract.clade(phy = tas,node = m)
+      b2 = age - ape::node.depth.edgelength(tas)[m]
    }
    m0 = tas$edge[which(tas$edge[,2] == m),1]
-   b1 = age - node.depth.edgelength(tas)[m0]
-   tas2 = paintSubTree(tas,node = m,state = "1",anc.state = "0", stem = (pars[7] - b2)/(b1 - b2))
-   plotSimmap(tas2,cols,lwd = 3,pts = F)   
+   b1 = age - ape::node.depth.edgelength(tas)[m0]
+   tas2 = phytools::paintSubTree(tas,node = m,state = "1",anc.state = "0", stem = (pars[7] - b2)/(b1 - b2))
+   phytools::plotSimmap(tas2,cols,lwd = 3,pts = F)   
 }
 out = list(tes = tes,tas = tas,L = L,tesS = tesS,tasS = tasS,tes2 = tes2,tas2 = tas2)
 return(out)
 
-}
\ No newline at end of file
+}
